#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rio-orphans
version:              0.1.2.0
visibility:           public
id:                   rio-orphans-0.1.2.0-IYlhzCa4G2lGrGmd7iVqA8
key:                  rio-orphans-0.1.2.0-IYlhzCa4G2lGrGmd7iVqA8
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio#readme
synopsis:             Orphan instances for the RIO type in the rio package
description:
    See README and Haddocks at <https://www.stackage.org/package/rio-orphans>

category:             Control
abi:                  a9bb5c4a3752f161961811cc318c8ba7
exposed:              True
exposed-modules:      RIO.Orphans
hidden-modules:       Paths_rio_orphans
import-dirs:          /usr/lib/ghc-9.6.6/site-local/rio-orphans-0.1.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rio-orphans-0.1.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rio-orphans-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-orphans
hs-libraries:         HSrio-orphans-0.1.2.0-IYlhzCa4G2lGrGmd7iVqA8
depends:
    base-4.18.2.1 exceptions-0.10.7
    fast-logger-3.2.4-KJh7fyhQdIVAb3GJDIN881
    monad-control-1.0.3.1-F55u9YDMbgE3oZm7b7lFt9
    monad-logger-0.3.42-LOVOH15E4izKhi87BCMM5A
    resourcet-1.2.6-ISzbKkOS7tA59m6DqAPsM
    rio-0.1.24.0-BnqaoM9zJ4LAPcLSBaeAta
    transformers-base-0.4.6.1-BIZMvltQUUfGciPvMzGFs8
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:   /usr/share/doc/haskell-rio-orphans/html/rio-orphans.haddock
haddock-html:         /usr/share/doc/haskell-rio-orphans/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

